@@ -15,6 +15,7 @@ class AstraEventHandler(AssistantEventHandler):
         self.logger = logging.getLogger(__name__)
         self.tools = {}
         self.tool_output = ToolOutput
+        self.file_search = None
         self.tool_call_results = None
         self.arguments = None
         self.stream = None
@@ -23,6 +24,11 @@ class AstraEventHandler(AssistantEventHandler):
     def register_tool(self, tool):
         self.tools[tool.to_function()['function']['name']] = tool
 
+    @override
+    def on_run_step_done(self, run_step) -> None:
+        for tool_call in run_step.step_details.tool_calls:
+            self.file_search = tool_call.file_search
+
     @override
     def on_tool_call_done(self, tool_call):
         self.logger.info(tool_call)
@@ -41,6 +47,7 @@ class AstraEventHandler(AssistantEventHandler):
                 tool_call_results_string = tool_call_results_obj
         else:
             tool_call_results_string = self.tool_call_results
+        print(f"tool_call.id {tool_call.id}")
         self.tool_output = ToolOutput(
             tool_call_id=tool_call.id,
             output=tool_call_results_string
