@@ -22,7 +22,11 @@ from openai.types import FileObject
 from openai.types.beta.threads import message_create_params, Message
 
 from dotenv import load_dotenv
-from openai.types.beta.vector_stores import VectorStoreFile
+try:
+    from openai.types.beta.vector_stores import VectorStoreFile
+except ImportError:
+    from openai.types.vector_stores import VectorStoreFile
+
 
 from astra_assistants import OpenAIWithDefaultKey, AsyncOpenAIWithDefaultKey
 
@@ -580,10 +584,6 @@ def enhance_copy_method(original_copy):
 def patch(client: Union[OpenAI, AsyncOpenAI]):
 
 
-    if client.api_key is not None and False:
-        pass
-
-
     if client.base_url == "https://api.openai.com/v1/":
         base_url = os.getenv("base_url") or os.getenv("BASE_URL", "https://open-assistant-ai.astra.datastax.com/v1")
         client.base_url=base_url
